@@ -22,7 +22,7 @@ class TestPyinstaller(unittest.TestCase):
 
     def test_finalize_opts(self):
         dist = Distribution()
-        pi = pyinstaller.pyinstaller(dist)
+        pi = pyinstaller.bdist_pyinstaller(dist)
         pi.target = "fake.py"
         pi.finalize_options()
         self.assertTrue( re.match(".+", pi.name) )
